
/****************************************************************************
 Title  :   C  file for the SRF08 FUNCTIONS library (srf08.c)
 Author:    Chris efstathiou hendrix@otenet.gr
 Date:      13/Jul/2002
 Software:  AVR-GCC with AVR-AS
 Target:    any AVR device
 Comments:  This software is FREE.

*****************************************************************************/

#include <io.h>
#include "i2c.h"
#include "lm75.h"


#define DELAY_LONG(x)     ({ unsigned long number_of_loops=(unsigned long)x;     \
                              __asm__ volatile ( "cp  %A0,__zero_reg__ \n\t"     \
                                                 "cpc %B0,__zero_reg__ \n\t"     \
                                                 "cpc %C0,__zero_reg__ \n\t"     \
                                                 "cpc %D0,__zero_reg__ \n\t"     \
                                                 "breq L_EXIT_%=       \n\t"     \
                                                 "L_%=:                \n\t"     \
                                                 "subi %A0,lo8(-(-1))  \n\t"     \
                                                 "sbci %B0,hi8(-(-1))  \n\t"     \
                                                 "sbci %C0,hlo8(-(-1)) \n\t"     \
                                                 "sbci %D0,hhi8(-(-1)) \n\t"     \
                                                 "brne L_%=            \n\t"     \
                                                 "L_EXIT_%=:           \n\t"     \
                                                 : /* NO OUTPUT */               \
                                                 : "w" (number_of_loops)         \
                                               );                                \
                          })                                        

#define TIME_L1_MS    ( 1*(F_CPU/6000) )             /* MUST USE A LONG FOR COUNTING TO BE ACCURATE  */
#define DELAY_MS(ms)  DELAY_LONG((TIME_L1_MS*ms))



/* Global Variables */
static unsigned char address=LM75_UNIT_0;

union i2c_union {
                    signed int    rx_word; 
                    unsigned char rx_byte[2];
                 } i2c;


/*#################################################################################################*/

void lm75_select_unit(unsigned char lm75_address)
{

/* Make the new i2c address the active one. */
address=lm75_address;                           

return;
}


signed int lm75_get_temp(void)
{
 signed int   lm75_temp=0;
 unsigned char komma;
DELAY_MS(LM75_DELAY); /* you should use a timer and an interrupt if possible */

    I2C_START_RX(address);
    lm75_temp=i2c_receive(I2C_QUIT);
    i2c.rx_byte[0]=i2c_receive(I2C_QUIT);
    i2c_stop();
    
    lm75_temp = lm75_temp * 10;
    
    komma = lm75_get_reg(0);
    
   	 if (komma == 132)		// Kommastelle?		
   	  {
     	   lm75_temp = lm75_temp + 5; 	// halbes Grad hinter dem Komma anhngen
    	  }
  
    
return(lm75_temp); 
}


signed int lm75_get_reg(unsigned char reg_number)
{

    I2C_START_TX(address);
    i2c_transmit(reg_number);
    I2C_START_RX(address);

    if(reg_number != 1)
      {
      	i2c.rx_byte[1]=i2c_receive(I2C_CONTINUE);
        i2c.rx_byte[0]=i2c_receive(I2C_QUIT);
      }
    else{ i2c.rx_byte[0]=i2c_receive(I2C_QUIT); i2c.rx_byte[1]=0; }

    i2c_stop();


return(i2c.rx_word);
}

void lm75_set_tos(signed char tos_temp)
{

    I2C_START_TX(address);
    i2c_transmit(LM75_TOS_REG);


    i2c_transmit(tos_temp);       
    i2c_transmit(0);

    i2c_stop();


return;
}

void lm75_set_hyst(signed char hyst_temp)
{


    I2C_START_TX(address);
    i2c_transmit(LM75_HYST_REG);

    i2c_transmit(hyst_temp);       
    i2c_transmit(0);

    i2c_stop();


return;
}

void lm75_configure(unsigned char config_byte)
{


    I2C_START_TX(address);
    i2c_transmit(LM75_CONFIG_REG);

    i2c_transmit(config_byte);       

    i2c_stop();


return;
}

/*######################################################################################################*/
/*                                         T H E   E N D                                                */
/*######################################################################################################*/

