
/****************************************************************************
 Title  :   C  file for the PCF8574 FUNCTIONS library (pcf8574.c)
 Author:    Daniel Mooney 
 Credits:   Chris efstathiou hendrix@otenet.gr
 Credits:   Mario Boller-Olfert (www.123-byte.de MICONOX)
 Credits:   others that have contributed above works
 Date:      16/Aug/2002
 Software:  AVR-GCC with AVR-AS
 Target:    any AVR device
 Comments:  This software is FREE.
            Requires i2c.c,i2c.h by Chris efstathiou

*****************************************************************************/

#include <io.h>
#include "i2c.h"
#include "pcf8574.h"

/* Global Variables */
/* unit address with default setting */
static unsigned char address = PCF8574_UNIT_0; /* (unit 0) */

/* conversion of 0-15 to actual address */
inline static unsigned char pcf8574_address(unsigned char unit)
{
  if(unit < 8) { return PCF8574_UNIT_0 + (unit << 1); }
  else { return PCF8574A_UNIT_0 + ((unit-8) << 1); }
}

/* select unit function */
/* after selecting unit all read,write,init will be on that unit */
void pcf8574_select_unit(unsigned char pcf8574_addr)
{
  /* convert if using unit number rather than address */
  if(pcf8574_addr<16) { pcf8574_addr = pcf8574_address(pcf8574_addr); }

  /* New address validity check */
  if((pcf8574_addr<PCF8574_UNIT_0 || pcf8574_addr>PCF8574_UNIT_7) && /*8574 */
     (pcf8574_addr<PCF8574A_UNIT_0 || pcf8574_addr>PCF8574A_UNIT_7)) /*8574A */
    { return; }                 /* not within valid address ranges */
  if(pcf8574_addr%2) { return; }  /* not in read range */

  /* Make the new i2c address the active one. */
  address=pcf8574_addr;

  return;
}

/* init function not needed but usefull to detect if unit is connected */
unsigned char pcf8574_init(void)
{
  unsigned char err;
  i2c_init();
  i2c_start();
  err = i2c_transmit(address);
  /* if no error init all 1 (pullup ready for input) same as powerup default */
  if (err == I2C_NO_ERROR) { i2c_transmit(0xFF); }
  i2c_stop();
  return (err);
}

/* read function */
unsigned char pcf8574_read(void)
{
  unsigned char ret;
  I2C_START_RX(address);
  ret = i2c_receive(I2C_QUIT);
  i2c_stop();

  return (ret);
}

/* write function */
unsigned char pcf8574_write(unsigned char val)
{
  unsigned char err;
  i2c_start();
  err = i2c_transmit(address);
  /* if no error write val */
  if (err == I2C_NO_ERROR) { i2c_transmit(val); }
  i2c_stop();

  return (err);
}

/*#####################################################################*/
/*                        T H E   E N D                                */
/*#####################################################################*/

