
/****************************************************************************
 Title  :   C  include file for the PCF8574 FUNCTIONS library (pcf8574.h)
 Author:    Daniel Mooney 
 Credits:   Chris efstathiou hendrix@otenet.gr
 Credits:   Mario Boller-Olfert (www.123-byte.de MICONOX)
 Credits:   others that have contributed above works
 Date:      16/Aug/2002
 Software:  AVR-GCC with AVR-AS
 Target:    any AVR device
 Comments:  This software is FREE.
            Requires i2c.c,i2c.h by Chris efstathiou

*****************************************************************************/

/* ######################################################################
 DESCRIPTION
   Address of PCF8574 is:
       +-----+-----+-----+-----+-----+-----+-----+-----+
       |  0  |  1  |  0  |  0  |  A2 |  A1 |  A0 | R/W |
       +-----+-----+-----+-----+-----+-----+-----+-----+
   Address of PCF8574A is:
       +-----+-----+-----+-----+-----+-----+-----+-----+
       |  0  |  1  |  1  |  1  |  A2 |  A1 |  A0 | R/W |
       +-----+-----+-----+-----+-----+-----+-----+-----+
   R/W==1 means: read operation

   In this Interface PCF8574 has unit addresses of 0 to 7
   and PCF8574A has unit addresses of 8 to 15.
   or the actual address as defined below
   #######################################################################*/
#ifndef PCF8574_H
#define PCF8574_H     1

/*######################################################################*/
/*                  START OF CONFIGURATION BLOCK                        */
/*######################################################################*/


//#define PCF 	TRUE
//#define LM_75  	FALSE
 
/*                  THERE IS NOTHING TO CONFIGURE                       */

/*######################################################################*/
/*                   END OF CONFIGURATION BLOCK                         */
/*######################################################################*/

/* Normally you shouldn't need to change anything */
/* Up to 16 PCF8574? units are possible on the I2C bus */
/* (8 x PCF8574 and 8 x PCF8574A) */

/* you can use pcf8574_select_unit(0) (unit 0-15)
   or pcf8574_select_unit(PCF8574_UNIT_0) as defined below */

/* only NEED PCF8574_UNIT_0 and PCF8574A_UNIT_0 (others are calculated) */
#define PCF8574_UNIT_0   0x40  /* PCF8574  (unit 0)  I2C address */
#define PCF8574_UNIT_1   0x42  /* PCF8574  (unit 1)  I2C address */
#define PCF8574_UNIT_2   0x44  /* PCF8574  (unit 2)  I2C address */
#define PCF8574_UNIT_3   0x46  /* PCF8574  (unit 3)  I2C address */
#define PCF8574_UNIT_4   0x48  /* PCF8574  (unit 4)  I2C address */
#define PCF8574_UNIT_5   0x4A  /* PCF8574  (unit 5)  I2C address */
#define PCF8574_UNIT_6   0x4C  /* PCF8574  (unit 6)  I2C address */
#define PCF8574_UNIT_7   0x4E  /* PCF8574  (unit 7)  I2C address */
#define PCF8574A_UNIT_0  0x70  /* PCF8574A (unit 8)  I2C address */
#define PCF8574A_UNIT_1  0x72  /* PCF8574A (unit 9)  I2C address */
#define PCF8574A_UNIT_2  0x74  /* PCF8574A (unit 10) I2C address */
#define PCF8574A_UNIT_3  0x76  /* PCF8574A (unit 11) I2C address */
#define PCF8574A_UNIT_4  0x78  /* PCF8574A (unit 12) I2C address */
#define PCF8574A_UNIT_5  0x7A  /* PCF8574A (unit 13) I2C address */
#define PCF8574A_UNIT_6  0x7C  /* PCF8574A (unit 14) I2C address */
#define PCF8574A_UNIT_7  0x7E  /* PCF8574A (unit 15) I2C address */

#define pcf8574_write_all_input()   pcf8574_write(0xFF)

#define LM75 0x90


/* Function Declarations */
extern void          pcf8574_select_unit(unsigned char pcf8574_addr);
extern unsigned char pcf8574_init(void);
extern unsigned char pcf8574_read(void);
extern unsigned char pcf8574_write(unsigned char val);

#endif  /* #ifndef PCF8574_H */

/*#####################################################################*/
/*                          T H E   E N D                              */
/*#####################################################################*/

